/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.dtstack.flink.example.function;

import com.dtstack.flink.example.bean.Person;
import org.apache.flink.api.java.tuple.Tuple2;
import org.apache.flink.configuration.Configuration;
import org.apache.flink.streaming.api.functions.sink.RichSinkFunction;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
 * @author dtstack
 * @create 2021-08-26 10:52
 * @description
 **/
public class DtStackSink extends RichSinkFunction<Tuple2<String, Integer>> {
    private static final Logger LOG = LoggerFactory.getLogger(DtStackSink.class);


    /**
     * 打开资源比如连接
     *
     * @param parameters parameters
     * @throws Exception
     */
    @Override
    public void open(Configuration parameters) throws Exception {
    }

    /**
     * 具体的sink代码在这里编写
     *
     * @throws Exception
     */
    @Override
    public void invoke(Tuple2<String, Integer> value) {
        try {
            LOG.info(value.toString());
        } catch (Exception e) {
            LOG.error(e.toString());
        }
    }

    /**
     * 释放资源比如连接
     *
     * @throws Exception
     */
    @Override
    public void close() throws Exception {
        super.close();
    }
}
